import flet as ft
from enum import Enum
from pathlib import Path
import re


class FluentIconStyle(Enum):
    FILLED = "filled"
    REGULAR = "regular"


class FluentIcons(Enum):
    ACCESS_TIME = "access_time"
    ACCESSIBILITY = "accessibility"
    ACCESSIBILITY_CHECKMARK = "accessibility_checkmark"
    ADD = "add"
    ADD_CIRCLE = "add_circle"
    ADD_SQUARE = "add_square"
    ADD_SUBTRACT_CIRCLE = "add_subtract_circle"
    AIRPLANE = "airplane"
    AIRPLANE_TAKE_OFF = "airplane_take_off"
    ALBUM = "album"
    ALBUM_ADD = "album_add"
    ALERT = "alert"
    ALERT_OFF = "alert_off"
    ALERT_ON = "alert_on"
    ALERT_SNOOZE = "alert_snooze"
    ALERT_URGENT = "alert_urgent"
    ALIGN_BOTTOM = "align_bottom"
    ALIGN_CENTER_HORIZONTAL = "align_center_horizontal"
    ALIGN_CENTER_VERTICAL = "align_center_vertical"
    ALIGN_LEFT = "align_left"
    ALIGN_RIGHT = "align_right"
    ALIGN_TOP = "align_top"
    ANIMAL_CAT = "animal_cat"
    ANIMAL_DOG = "animal_dog"
    ANIMAL_RABBIT = "animal_rabbit"
    ANIMAL_TURTLE = "animal_turtle"
    APP_FOLDER = "app_folder"
    APP_GENERIC = "app_generic"
    APP_RECENT = "app_recent"
    APP_STORE = "app_store"
    APP_TITLE = "app_title"
    APPROVALS_APP = "approvals_app"
    APPS = "apps"
    APPS_ADD_IN = "apps_add_in"
    APPS_LIST = "apps_list"
    APPS_LIST_DETAIL = "apps_list_detail"
    ARCHIVE = "archive"
    ARROW_AUTOFIT_CONTENT = "arrow_autofit_content"
    ARROW_AUTOFIT_DOWN = "arrow_autofit_down"
    ARROW_AUTOFIT_HEIGHT = "arrow_autofit_height"
    ARROW_AUTOFIT_HEIGHT_DOTTED = "arrow_autofit_height_dotted"
    ARROW_AUTOFIT_UP = "arrow_autofit_up"
    ARROW_AUTOFIT_WIDTH = "arrow_autofit_width"
    ARROW_AUTOFIT_WIDTH_DOTTED = "arrow_autofit_width_dotted"
    ARROW_BIDIRECTIONAL_UP_DOWN = "arrow_bidirectional_up_down"
    ARROW_BOUNCE = "arrow_bounce"
    ARROW_CIRCLE_DOWN = "arrow_circle_down"
    ARROW_CIRCLE_DOWN_DOUBLE = "arrow_circle_down_double"
    ARROW_CIRCLE_DOWN_RIGHT = "arrow_circle_down_right"
    ARROW_CIRCLE_DOWN_SPLIT = "arrow_circle_down_split"
    ARROW_CIRCLE_LEFT = "arrow_circle_left"
    ARROW_CIRCLE_RIGHT = "arrow_circle_right"
    ARROW_CIRCLE_UP = "arrow_circle_up"
    ARROW_CIRCLE_UP_LEFT = "arrow_circle_up_left"
    ARROW_CLOCKWISE = "arrow_clockwise"
    ARROW_CLOCKWISE_DASHES = "arrow_clockwise_dashes"
    ARROW_COLLAPSE_ALL = "arrow_collapse_all"
    ARROW_COUNTERCLOCKWISE = "arrow_counterclockwise"
    ARROW_COUNTERCLOCKWISE_DASHES = "arrow_counterclockwise_dashes"
    ARROW_CURVE_DOWN_LEFT = "arrow_curve_down_left"
    ARROW_DOWN = "arrow_down"
    ARROW_DOWN_LEFT = "arrow_down_left"
    ARROW_DOWNLOAD = "arrow_download"
    ARROW_ENTER_LEFT = "arrow_enter_left"
    ARROW_ENTER_UP = "arrow_enter_up"
    ARROW_EXPAND = "arrow_expand"
    ARROW_EXPORT_LTR = "arrow_export_ltr"
    ARROW_EXPORT_UP = "arrow_export_up"
    ARROW_FORWARD = "arrow_forward"
    ARROW_GROWTH = "arrow_growth"
    ARROW_HOOK_DOWN_LEFT = "arrow_hook_down_left"
    ARROW_HOOK_DOWN_RIGHT = "arrow_hook_down_right"
    ARROW_HOOK_UP_LEFT = "arrow_hook_up_left"
    ARROW_HOOK_UP_RIGHT = "arrow_hook_up_right"
    ARROW_IMPORT = "arrow_import"
    ARROW_LEFT = "arrow_left"
    ARROW_MAXIMIZE = "arrow_maximize"
    ARROW_MAXIMIZE_VERTICAL = "arrow_maximize_vertical"
    ARROW_MINIMIZE = "arrow_minimize"
    ARROW_MINIMIZE_VERTICAL = "arrow_minimize_vertical"
    ARROW_MOVE = "arrow_move"
    ARROW_NEXT = "arrow_next"
    ARROW_PREVIOUS = "arrow_previous"
    ARROW_REDO = "arrow_redo"
    ARROW_REPEAT_ALL = "arrow_repeat_all"
    ARROW_REPEAT_ALL_OFF = "arrow_repeat_all_off"
    ARROW_REPLY = "arrow_reply"
    ARROW_REPLY_ALL = "arrow_reply_all"
    ARROW_REPLY_DOWN = "arrow_reply_down"
    ARROW_RESET = "arrow_reset"
    ARROW_RIGHT = "arrow_right"
    ARROW_ROTATE_CLOCKWISE = "arrow_rotate_clockwise"
    ARROW_ROTATE_COUNTERCLOCKWISE = "arrow_rotate_counterclockwise"
    ARROW_ROUTING = "arrow_routing"
    ARROW_ROUTING_RECTANGLE_MULTIPLE = "arrow_routing_rectangle_multiple"
    ARROW_SORT = "arrow_sort"
    ARROW_SORT_DOWN = "arrow_sort_down"
    ARROW_SORT_UP = "arrow_sort_up"
    ARROW_SQUARE_DOWN = "arrow_square_down"
    ARROW_SWAP = "arrow_swap"
    ARROW_SYNC = "arrow_sync"
    ARROW_SYNC_CIRCLE = "arrow_sync_circle"
    ARROW_TRENDING = "arrow_trending"
    ARROW_TRENDING_CHECKMARK = "arrow_trending_checkmark"
    ARROW_TRENDING_LINES = "arrow_trending_lines"
    ARROW_TRENDING_SETTINGS = "arrow_trending_settings"
    ARROW_TURN_BIDIRECTIONAL_DOWN_RIGHT = "arrow_turn_bidirectional_down_right"
    ARROW_TURN_RIGHT = "arrow_turn_right"
    ARROW_UNDO = "arrow_undo"
    ARROW_UP = "arrow_up"
    ARROW_UP_LEFT = "arrow_up_left"
    ARROW_UP_RIGHT = "arrow_up_right"
    ARROW_UPLOAD = "arrow_upload"
    ARROWS_BIDIRECTIONAL = "arrows_bidirectional"
    ATTACH = "attach"
    ATTACH_ARROW_RIGHT = "attach_arrow_right"
    ATTACH_TEXT = "attach_text"
    AUTO_FIT_HEIGHT = "auto_fit_height"
    AUTO_FIT_WIDTH = "auto_fit_width"
    AUTOCORRECT = "autocorrect"
    AUTOFIT_CONTENT = "autofit_content"
    AUTOSUM = "autosum"
    BACKPACK = "backpack"
    BACKPACK_ADD = "backpack_add"
    BACKSPACE = "backspace"
    BADGE = "badge"
    BALLOON = "balloon"
    BARCODE_SCANNER = "barcode_scanner"
    BATTERY_0 = "battery_0"
    BATTERY_1 = "battery_1"
    BATTERY_2 = "battery_2"
    BATTERY_3 = "battery_3"
    BATTERY_4 = "battery_4"
    BATTERY_5 = "battery_5"
    BATTERY_6 = "battery_6"
    BATTERY_7 = "battery_7"
    BATTERY_8 = "battery_8"
    BATTERY_9 = "battery_9"
    BATTERY_CHARGE = "battery_charge"
    BATTERY_CHECKMARK = "battery_checkmark"
    BATTERY_FULL = "battery_full"
    BATTERY_SAVER = "battery_saver"
    BATTERY_WARNING = "battery_warning"
    BEACH = "beach"
    BEAKER = "beaker"
    BEAKER_EDIT = "beaker_edit"
    BED = "bed"
    BIN_FULL = "bin_full"
    BLOCK = "block"
    BLUETOOTH = "bluetooth"
    BLUETOOTH_CONNECTED = "bluetooth_connected"
    BLUETOOTH_DISABLED = "bluetooth_disabled"
    BLUETOOTH_SEARCHING = "bluetooth_searching"
    BLUR = "blur"
    BOARD = "board"
    BOARD_SPLIT = "board_split"
    BOOK = "book"
    BOOK_ADD = "book_add"
    BOOK_CLOCK = "book_clock"
    BOOK_COINS = "book_coins"
    BOOK_COMPASS = "book_compass"
    BOOK_CONTACTS = "book_contacts"
    BOOK_DATABASE = "book_database"
    BOOK_EXCLAMATION_MARK = "book_exclamation_mark"
    BOOK_GLOBE = "book_globe"
    BOOK_INFORMATION = "book_information"
    BOOK_LETTER = "book_letter"
    BOOK_NUMBER = "book_number"
    BOOK_OPEN = "book_open"
    BOOK_OPEN_GLOBE = "book_open_globe"
    BOOK_OPEN_MICROPHONE = "book_open_microphone"
    BOOK_PULSE = "book_pulse"
    BOOK_QUESTION_MARK = "book_question_mark"
    BOOK_QUESTION_MARK_RTL = "book_question_mark_rtl"
    BOOK_SEARCH = "book_search"
    BOOK_STAR = "book_star"
    BOOK_THETA = "book_theta"
    BOOK_TOOLBOX = "book_toolbox"
    BOOKMARK = "bookmark"
    BOOKMARK_ADD = "bookmark_add"
    BOOKMARK_MULTIPLE = "bookmark_multiple"
    BOOKMARK_OFF = "bookmark_off"
    BORDER = "border"
    BORDER_ALL = "border_all"
    BORDER_BOTTOM = "border_bottom"
    BORDER_BOTTOM_DOUBLE = "border_bottom_double"
    BORDER_BOTTOM_THICK = "border_bottom_thick"
    BORDER_LEFT = "border_left"
    BORDER_OUTSIDE = "border_outside"
    BORDER_OUTSIDE_THICK = "border_outside_thick"
    BORDER_RIGHT = "border_right"
    BORDER_TOP = "border_top"
    BORDER_TOP_BOTTOM = "border_top_bottom"
    BORDER_TOP_BOTTOM_DOUBLE = "border_top_bottom_double"
    BORDER_TOP_BOTTOM_THICK = "border_top_bottom_thick"
    BOT = "bot"
    BOT_ADD = "bot_add"
    BOWL_CHOPSTICKS = "bowl_chopsticks"
    BOX_EDIT = "box_edit"
    BOX_TOOLBOX = "box_toolbox"
    BRACES_VARIABLE = "braces_variable"
    BRAIN_CIRCUIT = "brain_circuit"
    BRANCH = "branch"
    BRANCH_COMPARE = "branch_compare"
    BRANCH_FORK = "branch_fork"
    BRIEFCASE = "briefcase"
    BRIEFCASE_MEDICAL = "briefcase_medical"
    BRIEFCASE_OFF = "briefcase_off"
    BROAD_ACTIVITY_FEED = "broad_activity_feed"
    BROOM = "broom"
    BUG = "bug"
    BUILDING = "building"
    BUILDING_BANK = "building_bank"
    BUILDING_BANK_LINK = "building_bank_link"
    BUILDING_BANK_TOOLBOX = "building_bank_toolbox"
    BUILDING_FACTORY = "building_factory"
    BUILDING_GOVERNMENT = "building_government"
    BUILDING_MULTIPLE = "building_multiple"
    BUILDING_RETAIL = "building_retail"
    BUILDING_RETAIL_MONEY = "building_retail_money"
    BUILDING_RETAIL_SHIELD = "building_retail_shield"
    BUILDING_RETAIL_TOOLBOX = "building_retail_toolbox"
    BUILDING_SHOP = "building_shop"
    BUILDING_SKYSCRAPER = "building_skyscraper"
    CALCULATOR = "calculator"
    CALCULATOR_MULTIPLE = "calculator_multiple"
    CALENDAR_3_DAY = "calendar_3_day"
    CALENDAR_ADD = "calendar_add"
    CALENDAR_AGENDA = "calendar_agenda"
    CALENDAR_ARROW_DOWN = "calendar_arrow_down"
    CALENDAR_ASSISTANT = "calendar_assistant"
    CALENDAR_CANCEL = "calendar_cancel"
    CALENDAR_CHECKMARK = "calendar_checkmark"
    CALENDAR_CLOCK = "calendar_clock"
    CALENDAR_DAY = "calendar_day"
    CALENDAR_EDIT = "calendar_edit"
    CALENDAR_EMPTY = "calendar_empty"
    CALENDAR_ERROR = "calendar_error"
    CALENDAR_LTR = "calendar_ltr"
    CALENDAR_MONTH = "calendar_month"
    CALENDAR_MULTIPLE = "calendar_multiple"
    CALENDAR_OVERDUE = "calendar_overdue"
    CALENDAR_PERSON = "calendar_person"
    CALENDAR_QUESTION_MARK = "calendar_question_mark"
    CALENDAR_REPLY = "calendar_reply"
    CALENDAR_RTL = "calendar_rtl"
    CALENDAR_STAR = "calendar_star"
    CALENDAR_SYNC = "calendar_sync"
    CALENDAR_TODAY = "calendar_today"
    CALENDAR_WEEK_NUMBERS = "calendar_week_numbers"
    CALENDAR_WEEK_START = "calendar_week_start"
    CALENDAR_WORK_WEEK = "calendar_work_week"
    CALL = "call"
    CALL_ADD = "call_add"
    CALL_CHECKMARK = "call_checkmark"
    CALL_DISMISS = "call_dismiss"
    CALL_END = "call_end"
    CALL_FORWARD = "call_forward"
    CALL_INBOUND = "call_inbound"
    CALL_MISSED = "call_missed"
    CALL_OUTBOUND = "call_outbound"
    CALL_PARK = "call_park"
    CALL_PAUSE = "call_pause"
    CALL_PROHIBITED = "call_prohibited"
    CALLIGRAPHY_PEN = "calligraphy_pen"
    CAMERA = "camera"
    CAMERA_ADD = "camera_add"
    CAMERA_DOME = "camera_dome"
    CAMERA_OFF = "camera_off"
    CAMERA_SWITCH = "camera_switch"
    CARET = "caret"
    CARET_DOWN = "caret_down"
    CARET_DOWN_LEFT = "caret_down_left"
    CARET_LEFT = "caret_left"
    CARET_RIGHT = "caret_right"
    CARET_UP = "caret_up"
    CART = "cart"
    CAST = "cast"
    CELLULAR_3G = "cellular_3g"
    CELLULAR_4G = "cellular_4g"
    CELLULAR_5G = "cellular_5g"
    CELLULAR_DATA_1 = "cellular_data_1"
    CELLULAR_DATA_2 = "cellular_data_2"
    CELLULAR_DATA_3 = "cellular_data_3"
    CELLULAR_DATA_4 = "cellular_data_4"
    CELLULAR_DATA_5 = "cellular_data_5"
    CELLULAR_DATA_CELLULAR_OFF = "cellular_data_cellular_off"
    CELLULAR_DATA_CELLULAR_UNAVAILABLE = "cellular_data_cellular_unavailable"
    CELLULAR_DATA_UNAVAILABLE = "cellular_data_unavailable"
    CELLULAR_WARNING = "cellular_warning"
    CENTER_HORIZONTAL = "center_horizontal"
    CENTER_VERTICAL = "center_vertical"
    CERTIFICATE = "certificate"
    CHANNEL = "channel"
    CHANNEL_ADD = "channel_add"
    CHANNEL_ALERT = "channel_alert"
    CHANNEL_ARROW_LEFT = "channel_arrow_left"
    CHANNEL_DISMISS = "channel_dismiss"
    CHANNEL_SHARE = "channel_share"
    CHANNEL_SUBTRACT = "channel_subtract"
    CHART_PERSON = "chart_person"
    CHAT = "chat"
    CHAT_BUBBLES_QUESTION = "chat_bubbles_question"
    CHAT_HELP = "chat_help"
    CHAT_MULTIPLE = "chat_multiple"
    CHAT_OFF = "chat_off"
    CHAT_SETTINGS = "chat_settings"
    CHAT_VIDEO = "chat_video"
    CHAT_WARNING = "chat_warning"
    CHECK = "check"
    CHECKBOX_1 = "checkbox_1"
    CHECKBOX_2 = "checkbox_2"
    CHECKBOX_ARROW_RIGHT = "checkbox_arrow_right"
    CHECKBOX_CHECKED = "checkbox_checked"
    CHECKBOX_INDETERMINATE = "checkbox_indeterminate"
    CHECKBOX_PERSON = "checkbox_person"
    CHECKBOX_UNCHECKED = "checkbox_unchecked"
    CHECKBOX_WARNING = "checkbox_warning"
    CHECKMARK = "checkmark"
    CHECKMARK_CIRCLE = "checkmark_circle"
    CHECKMARK_LOCK = "checkmark_lock"
    CHECKMARK_SQUARE = "checkmark_square"
    CHEVRON_CIRCLE_DOWN = "chevron_circle_down"
    CHEVRON_CIRCLE_RIGHT = "chevron_circle_right"
    CHEVRON_DOWN = "chevron_down"
    CHEVRON_LEFT = "chevron_left"
    CHEVRON_RIGHT = "chevron_right"
    CHEVRON_UP = "chevron_up"
    CHEVRON_UP_DOWN = "chevron_up_down"
    CIRCLE = "circle"
    CIRCLE_EDIT = "circle_edit"
    CIRCLE_HALF_FILL = "circle_half_fill"
    CIRCLE_LINE = "circle_line"
    CIRCLE_SMALL = "circle_small"
    CITY = "city"
    CLASS = "class"
    CLASSIFICATION = "classification"
    CLEAR_FORMATTING = "clear_formatting"
    CLIPBOARD = "clipboard"
    CLIPBOARD_ARROW_RIGHT = "clipboard_arrow_right"
    CLIPBOARD_CHECKMARK = "clipboard_checkmark"
    CLIPBOARD_CODE = "clipboard_code"
    CLIPBOARD_ERROR = "clipboard_error"
    CLIPBOARD_HEART = "clipboard_heart"
    CLIPBOARD_IMAGE = "clipboard_image"
    CLIPBOARD_LETTER = "clipboard_letter"
    CLIPBOARD_LINK = "clipboard_link"
    CLIPBOARD_MORE = "clipboard_more"
    CLIPBOARD_PASTE = "clipboard_paste"
    CLIPBOARD_PULSE = "clipboard_pulse"
    CLIPBOARD_SEARCH = "clipboard_search"
    CLIPBOARD_SETTINGS = "clipboard_settings"
    CLIPBOARD_TASK = "clipboard_task"
    CLIPBOARD_TASK_ADD = "clipboard_task_add"
    CLIPBOARD_TASK_LIST_LTR = "clipboard_task_list_ltr"
    CLIPBOARD_TASK_LIST_RTL = "clipboard_task_list_rtl"
    CLIPBOARD_TEXT_LTR = "clipboard_text_ltr"
    CLIPBOARD_TEXT_RTL = "clipboard_text_rtl"
    CLOCK = "clock"
    CLOCK_ALARM = "clock_alarm"
    CLOCK_ARROW_DOWNLOAD = "clock_arrow_download"
    CLOCK_DISMISS = "clock_dismiss"
    CLOSED_CAPTION = "closed_caption"
    CLOSED_CAPTION_OFF = "closed_caption_off"
    CLOUD = "cloud"
    CLOUD_ARROW_DOWN = "cloud_arrow_down"
    CLOUD_ARROW_UP = "cloud_arrow_up"
    CLOUD_BACKUP = "cloud_backup"
    CLOUD_CHECKMARK = "cloud_checkmark"
    CLOUD_DISMISS = "cloud_dismiss"
    CLOUD_DOWNLOAD = "cloud_download"
    CLOUD_FLOW = "cloud_flow"
    CLOUD_OFF = "cloud_off"
    CLOUD_OFFLINE = "cloud_offline"
    CLOUD_SWAP = "cloud_swap"
    CLOUD_SYNC = "cloud_sync"
    CLOUD_SYNC_COMPLETE = "cloud_sync_complete"
    CLOUD_WORDS = "cloud_words"
    CODE = "code"
    COLLECTIONS = "collections"
    COLLECTIONS_ADD = "collections_add"
    COLOR = "color"
    COLOR_BACKGROUND = "color_background"
    COLOR_BACKGROUND_ACCENT = "color_background_accent"
    COLOR_FILL = "color_fill"
    COLOR_FILL_ACCENT = "color_fill_accent"
    COLOR_LINE = "color_line"
    COLOR_LINE_ACCENT = "color_line_accent"
    COLUMN_EDIT = "column_edit"
    COLUMN_TRIPLE = "column_triple"
    COLUMN_TRIPLE_EDIT = "column_triple_edit"
    COMMA = "comma"
    COMMENT = "comment"
    COMMENT_ADD = "comment_add"
    COMMENT_ARROW_LEFT = "comment_arrow_left"
    COMMENT_ARROW_RIGHT = "comment_arrow_right"
    COMMENT_CHECKMARK = "comment_checkmark"
    COMMENT_DISMISS = "comment_dismiss"
    COMMENT_EDIT = "comment_edit"
    COMMENT_LIGHTNING = "comment_lightning"
    COMMENT_MENTION = "comment_mention"
    COMMENT_MULTIPLE = "comment_multiple"
    COMMENT_MULTIPLE_CHECKMARK = "comment_multiple_checkmark"
    COMMENT_NOTE = "comment_note"
    COMMENT_OFF = "comment_off"
    COMMUNICATION = "communication"
    COMMUNICATION_PERSON = "communication_person"
    COMPASS_NORTHWEST = "compass_northwest"
    COMPONENT_2_DOUBLE_TAP_SWIPE_DOWN = "component_2_double_tap_swipe_down"
    COMPONENT_2_DOUBLE_TAP_SWIPE_UP = "component_2_double_tap_swipe_up"
    COMPOSE = "compose"
    CONFERENCE_ROOM = "conference_room"
    CONNECTOR = "connector"
    CONTACT_CARD = "contact_card"
    CONTACT_CARD_GROUP = "contact_card_group"
    CONTENT_SETTINGS = "content_settings"
    CONTRACT_DOWN_LEFT = "contract_down_left"
    CONTROL_BUTTON = "control_button"
    CONVERT_RANGE = "convert_range"
    CONVERT_TO_TABLE = "convert_to_table"
    CONVERT_TO_TEXT = "convert_to_text"
    CONVERT_TO_TYPE = "convert_to_type"
    COOKIES = "cookies"
    COPY = "copy"
    COPY_ADD = "copy_add"
    COPY_ARROW_RIGHT = "copy_arrow_right"
    COUCH = "couch"
    CREDIT_CARD_PERSON = "credit_card_person"
    CREDIT_CARD_TOOLBOX = "credit_card_toolbox"
    CROP = "crop"
    CROP_INTERIM = "crop_interim"
    CROP_INTERIM_OFF = "crop_interim_off"
    CUBE = "cube"
    CUBE_SYNC = "cube_sync"
    CURRENCY_DOLLAR_EURO = "currency_dollar_euro"
    CURRENCY_DOLLAR_RUPEE = "currency_dollar_rupee"
    CURSOR = "cursor"
    CURSOR_CLICK = "cursor_click"
    CURSOR_HOVER = "cursor_hover"
    CURSOR_HOVER_OFF = "cursor_hover_off"
    CUT = "cut"
    DARK_THEME = "dark_theme"
    DATA_AREA = "data_area"
    DATA_BAR_HORIZONTAL = "data_bar_horizontal"
    DATA_BAR_VERTICAL = "data_bar_vertical"
    DATA_BAR_VERTICAL_ADD = "data_bar_vertical_add"
    DATA_FUNNEL = "data_funnel"
    DATA_HISTOGRAM = "data_histogram"
    DATA_LINE = "data_line"
    DATA_PIE = "data_pie"
    DATA_SCATTER = "data_scatter"
    DATA_SUNBURST = "data_sunburst"
    DATA_TREEMAP = "data_treemap"
    DATA_TRENDING = "data_trending"
    DATA_USAGE = "data_usage"
    DATA_USAGE_EDIT = "data_usage_edit"
    DATA_WATERFALL = "data_waterfall"
    DATA_WHISKER = "data_whisker"
    DATABASE = "database"
    DATABASE_LINK = "database_link"
    DATABASE_SEARCH = "database_search"
    DECIMAL_ARROW_LEFT = "decimal_arrow_left"
    DECIMAL_ARROW_RIGHT = "decimal_arrow_right"
    DELETE = "delete"
    DELETE_DISMISS = "delete_dismiss"
    DELETE_OFF = "delete_off"
    DENTIST = "dentist"
    DESIGN_IDEAS = "design_ideas"
    DESKTOP = "desktop"
    DESKTOP_ARROW_RIGHT = "desktop_arrow_right"
    DESKTOP_KEYBOARD = "desktop_keyboard"
    DESKTOP_PULSE = "desktop_pulse"
    DESKTOP_SPEAKER = "desktop_speaker"
    DESKTOP_SPEAKER_OFF = "desktop_speaker_off"
    DEVELOPER_BOARD = "developer_board"
    DEVICE_EQ = "device_eq"
    DEVICE_MEETING_ROOM = "device_meeting_room"
    DEVICE_MEETING_ROOM_REMOTE = "device_meeting_room_remote"
    DIAGRAM = "diagram"
    DIALPAD = "dialpad"
    DIALPAD_OFF = "dialpad_off"
    DIRECTIONS = "directions"
    DISMISS = "dismiss"
    DISMISS_CIRCLE = "dismiss_circle"
    DISMISS_SQUARE = "dismiss_square"
    DIVERSITY = "diversity"
    DIVIDER_SHORT = "divider_short"
    DIVIDER_TALL = "divider_tall"
    DOCK = "dock"
    DOCK_PANEL_LEFT = "dock_panel_left"
    DOCK_PANEL_RIGHT = "dock_panel_right"
    DOCK_ROW = "dock_row"
    DOCTOR = "doctor"
    DOCUMENT = "document"
    DOCUMENT_ADD = "document_add"
    DOCUMENT_ARROW_LEFT = "document_arrow_left"
    DOCUMENT_ARROW_RIGHT = "document_arrow_right"
    DOCUMENT_BRIEFCASE = "document_briefcase"
    DOCUMENT_BULLET_LIST = "document_bullet_list"
    DOCUMENT_BULLET_LIST_CLOCK = "document_bullet_list_clock"
    DOCUMENT_BULLET_LIST_OFF = "document_bullet_list_off"
    DOCUMENT_CATCH_UP = "document_catch_up"
    DOCUMENT_CHECKMARK = "document_checkmark"
    DOCUMENT_CHEVRON_DOUBLE = "document_chevron_double"
    DOCUMENT_COPY = "document_copy"
    DOCUMENT_CSS = "document_css"
    DOCUMENT_DISMISS = "document_dismiss"
    DOCUMENT_EDIT = "document_edit"
    DOCUMENT_ENDNOTE = "document_endnote"
    DOCUMENT_ERROR = "document_error"
    DOCUMENT_FOOTER = "document_footer"
    DOCUMENT_FOOTER_DISMISS = "document_footer_dismiss"
    DOCUMENT_FOOTER_REMOVE = "document_footer_remove"
    DOCUMENT_HEADER = "document_header"
    DOCUMENT_HEADER_DISMISS = "document_header_dismiss"
    DOCUMENT_HEADER_FOOTER = "document_header_footer"
    DOCUMENT_HEADER_REMOVE = "document_header_remove"
    DOCUMENT_HEART = "document_heart"
    DOCUMENT_HEART_PULSE = "document_heart_pulse"
    DOCUMENT_JAVASCRIPT = "document_javascript"
    DOCUMENT_LANDSCAPE = "document_landscape"
    DOCUMENT_LANDSCAPE_DATA = "document_landscape_data"
    DOCUMENT_LINK = "document_link"
    DOCUMENT_MARGINS = "document_margins"
    DOCUMENT_MULTIPLE = "document_multiple"
    DOCUMENT_MULTIPLE_PERCENT = "document_multiple_percent"
    DOCUMENT_MULTIPLE_PROHIBITED = "document_multiple_prohibited"
    DOCUMENT_ONE_PAGE = "document_one_page"
    DOCUMENT_PAGE_BOTTOM_CENTER = "document_page_bottom_center"
    DOCUMENT_PAGE_BOTTOM_LEFT = "document_page_bottom_left"
    DOCUMENT_PAGE_BOTTOM_RIGHT = "document_page_bottom_right"
    DOCUMENT_PAGE_BREAK = "document_page_break"
    DOCUMENT_PAGE_NUMBER = "document_page_number"
    DOCUMENT_PAGE_TOP_CENTER = "document_page_top_center"
    DOCUMENT_PAGE_TOP_LEFT = "document_page_top_left"
    DOCUMENT_PAGE_TOP_RIGHT = "document_page_top_right"
    DOCUMENT_PDF = "document_pdf"
    DOCUMENT_PERCENT = "document_percent"
    DOCUMENT_PILL = "document_pill"
    DOCUMENT_PROHIBITED = "document_prohibited"
    DOCUMENT_QUESTION_MARK = "document_question_mark"
    DOCUMENT_RIBBON = "document_ribbon"
    DOCUMENT_SAVE = "document_save"
    DOCUMENT_SEARCH = "document_search"
    DOCUMENT_SPLIT_HINT = "document_split_hint"
    DOCUMENT_SPLIT_HINT_OFF = "document_split_hint_off"
    DOCUMENT_SYNC = "document_sync"
    DOCUMENT_TABLE = "document_table"
    DOCUMENT_TEXT = "document_text"
    DOCUMENT_TEXT_LINK = "document_text_link"
    DOCUMENT_TOOLBOX = "document_toolbox"
    DOCUMENT_WIDTH = "document_width"
    DOOR_ARROW_LEFT = "door_arrow_left"
    DOOR_TAG = "door_tag"
    DOUBLE_SWIPE_DOWN = "double_swipe_down"
    DOUBLE_SWIPE_UP = "double_swipe_up"
    DRAFTS = "drafts"
    DRAG = "drag"
    DRAW_SHAPE = "draw_shape"
    DRAW_TEXT = "draw_text"
    DRINK_BEER = "drink_beer"
    DRINK_COFFEE = "drink_coffee"
    DRINK_MARGARITA = "drink_margarita"
    DRINK_TO_GO = "drink_to_go"
    DRINK_WINE = "drink_wine"
    DRIVE_TRAIN = "drive_train"
    DROP = "drop"
    DUAL_SCREEN = "dual_screen"
    DUAL_SCREEN_ADD = "dual_screen_add"
    DUAL_SCREEN_ARROW_RIGHT = "dual_screen_arrow_right"
    DUAL_SCREEN_ARROW_UP = "dual_screen_arrow_up"
    DUAL_SCREEN_CLOCK = "dual_screen_clock"
    DUAL_SCREEN_CLOSED_ALERT = "dual_screen_closed_alert"
    DUAL_SCREEN_DESKTOP = "dual_screen_desktop"
    DUAL_SCREEN_DISMISS = "dual_screen_dismiss"
    DUAL_SCREEN_GROUP = "dual_screen_group"
    DUAL_SCREEN_HEADER = "dual_screen_header"
    DUAL_SCREEN_LOCK = "dual_screen_lock"
    DUAL_SCREEN_MIRROR = "dual_screen_mirror"
    DUAL_SCREEN_PAGINATION = "dual_screen_pagination"
    DUAL_SCREEN_SETTINGS = "dual_screen_settings"
    DUAL_SCREEN_SPAN = "dual_screen_span"
    DUAL_SCREEN_SPEAKER = "dual_screen_speaker"
    DUAL_SCREEN_STATUS_BAR = "dual_screen_status_bar"
    DUAL_SCREEN_TABLET = "dual_screen_tablet"
    DUAL_SCREEN_UPDATE = "dual_screen_update"
    DUAL_SCREEN_VERTICAL_SCROLL = "dual_screen_vertical_scroll"
    DUAL_SCREEN_VIBRATE = "dual_screen_vibrate"
    DUMBBELL = "dumbbell"
    EARTH = "earth"
    EDIT = "edit"
    EDIT_OFF = "edit_off"
    EDIT_SETTINGS = "edit_settings"
    EMOJI = "emoji"
    EMOJI_ADD = "emoji_add"
    EMOJI_ANGRY = "emoji_angry"
    EMOJI_HAND = "emoji_hand"
    EMOJI_LAUGH = "emoji_laugh"
    EMOJI_MEH = "emoji_meh"
    EMOJI_MULTIPLE = "emoji_multiple"
    EMOJI_SAD = "emoji_sad"
    EMOJI_SURPRISE = "emoji_surprise"
    ENGINE = "engine"
    EQUAL_OFF = "equal_off"
    ERASER = "eraser"
    ERASER_MEDIUM = "eraser_medium"
    ERASER_SEGMENT = "eraser_segment"
    ERASER_SMALL = "eraser_small"
    ERASER_TOOL = "eraser_tool"
    ERROR_CIRCLE = "error_circle"
    EXPAND_UP_LEFT = "expand_up_left"
    EXPAND_UP_RIGHT = "expand_up_right"
    EXTENDED_DOCK = "extended_dock"
    EXTENSION = "extension"
    EYE_HIDE = "eye_hide"
    EYE_SHOW = "eye_show"
    EYE_TRACKING_OFF = "eye_tracking_off"
    EYE_TRACKING_ON = "eye_tracking_on"
    EYEDROPPER = "eyedropper"
    F_STOP = "f_stop"
    FAST_ACCELERATION = "fast_acceleration"
    FAST_FORWARD = "fast_forward"
    FILTER = "filter"
    FILTER_DISMISS = "filter_dismiss"
    FILTER_SYNC = "filter_sync"
    FINGERPRINT = "fingerprint"
    FIXED_WIDTH = "fixed_width"
    FLAG = "flag"
    FLAG_OFF = "flag_off"
    FLAG_PRIDE = "flag_pride"
    FLASH_AUTO = "flash_auto"
    FLASH_CHECKMARK = "flash_checkmark"
    FLASH_OFF = "flash_off"
    FLASH_ON = "flash_on"
    FLASHLIGHT = "flashlight"
    FLASHLIGHT_OFF = "flashlight_off"
    FLIP_HORIZONTAL = "flip_horizontal"
    FLIP_VERTICAL = "flip_vertical"
    FLUENT = "fluent"
    FLUID = "fluid"
    FOLDER = "folder"
    FOLDER_ADD = "folder_add"
    FOLDER_ARROW_RIGHT = "folder_arrow_right"
    FOLDER_ARROW_UP = "folder_arrow_up"
    FOLDER_LINK = "folder_link"
    FOLDER_OPEN = "folder_open"
    FOLDER_PROHIBITED = "folder_prohibited"
    FOLDER_SWAP = "folder_swap"
    FOLDER_ZIP = "folder_zip"
    FONT_DECREASE = "font_decrease"
    FONT_INCREASE = "font_increase"
    FONT_SPACE_TRACKING_IN = "font_space_tracking_in"
    FONT_SPACE_TRACKING_OUT = "font_space_tracking_out"
    FOOD = "food"
    FOOD_CAKE = "food_cake"
    FOOD_EGG = "food_egg"
    FOOD_PIZZA = "food_pizza"
    FOOD_TOAST = "food_toast"
    FORM_NEW = "form_new"
    FPS = "fps"
    FPS_120 = "fps_120"
    FPS_30 = "fps_30"
    FPS_60 = "fps_60"
    FPS_960 = "fps_960"
    FULL_SCREEN_MAXIMIZE = "full_screen_maximize"
    FULL_SCREEN_MINIMIZE = "full_screen_minimize"
    GAMES = "games"
    GANTT_CHART = "gantt_chart"
    GAS = "gas"
    GAS_PUMP = "gas_pump"
    GAUGE = "gauge"
    GAVEL = "gavel"
    GESTURE = "gesture"
    GIF = "gif"
    GIFT = "gift"
    GIFT_CARD_ADD = "gift_card_add"
    GLANCE = "glance"
    GLASSES = "glasses"
    GLASSES_OFF = "glasses_off"
    GLOBE = "globe"
    GLOBE_ADD = "globe_add"
    GLOBE_CLOCK = "globe_clock"
    GLOBE_DESKTOP = "globe_desktop"
    GLOBE_LOCATION = "globe_location"
    GLOBE_PERSON = "globe_person"
    GLOBE_SEARCH = "globe_search"
    GLOBE_SHIELD = "globe_shield"
    GLOBE_SURFACE = "globe_surface"
    GLOBE_VIDEO = "globe_video"
    GRID = "grid"
    GRID_DOTS = "grid_dots"
    GROUP = "group"
    GROUP_DISMISS = "group_dismiss"
    GROUP_LIST = "group_list"
    GROUP_RETURN = "group_return"
    GUARDIAN = "guardian"
    GUEST = "guest"
    GUEST_ADD = "guest_add"
    GUITAR = "guitar"
    HAND_DRAW = "hand_draw"
    HAND_LEFT = "hand_left"
    HAND_RIGHT = "hand_right"
    HANDSHAKE = "handshake"
    HAT_GRADUATION = "hat_graduation"
    HD = "hd"
    HDR = "hdr"
    HEADPHONES = "headphones"
    HEADPHONES_SOUND_WAVE = "headphones_sound_wave"
    HEADSET = "headset"
    HEADSET_ADD = "headset_add"
    HEADSET_VR = "headset_vr"
    HEART = "heart"
    HEART_PULSE = "heart_pulse"
    HIGHLIGHT = "highlight"
    HIGHLIGHT_ACCENT = "highlight_accent"
    HISTORY = "history"
    HOME = "home"
    HOME_ADD = "home_add"
    HOME_CHECKMARK = "home_checkmark"
    HOME_PERSON = "home_person"
    ICONS = "icons"
    IMAGE = "image"
    IMAGE_ADD = "image_add"
    IMAGE_ALT_TEXT = "image_alt_text"
    IMAGE_ARROW_BACK = "image_arrow_back"
    IMAGE_ARROW_COUNTERCLOCKWISE = "image_arrow_counterclockwise"
    IMAGE_ARROW_FORWARD = "image_arrow_forward"
    IMAGE_COPY = "image_copy"
    IMAGE_EDIT = "image_edit"
    IMAGE_GLOBE = "image_globe"
    IMAGE_MULTIPLE = "image_multiple"
    IMAGE_OFF = "image_off"
    IMAGE_PROHIBITED = "image_prohibited"
    IMAGE_REFLECTION = "image_reflection"
    IMAGE_SEARCH = "image_search"
    IMAGE_SHADOW = "image_shadow"
    IMMERSIVE_READER = "immersive_reader"
    IMPORTANT = "important"
    INCOGNITO = "incognito"
    INFO = "info"
    INK_STROKE = "ink_stroke"
    INKING_TOOL = "inking_tool"
    INKING_TOOL_ACCENT = "inking_tool_accent"
    INPRIVATE_ACCOUNT = "inprivate_account"
    IOS_ARROW_LEFT = "ios_arrow_left"
    IOS_ARROW_LTR = "ios_arrow_ltr"
    IOS_ARROW_RIGHT = "ios_arrow_right"
    IOS_ARROW_RTL = "ios_arrow_rtl"
    IOT = "iot"
    JAVASCRIPT = "javascript"
    KEY = "key"
    KEYBOARD = "keyboard"
    KEYBOARD_123 = "keyboard_123"
    KEYBOARD_DOCK = "keyboard_dock"
    KEYBOARD_LAYOUT_FLOAT = "keyboard_layout_float"
    KEYBOARD_LAYOUT_ONE_HANDED_LEFT = "keyboard_layout_one_handed_left"
    KEYBOARD_LAYOUT_RESIZE = "keyboard_layout_resize"
    KEYBOARD_LAYOUT_SPLIT = "keyboard_layout_split"
    KEYBOARD_SHIFT = "keyboard_shift"
    KEYBOARD_SHIFT_UPPERCASE = "keyboard_shift_uppercase"
    KEYBOARD_TAB = "keyboard_tab"
    LAPTOP = "laptop"
    LASSO = "lasso"
    LAUNCHER_SETTINGS = "launcher_settings"
    LAYER = "layer"
    LEAF_ONE = "leaf_one"
    LEAF_THREE = "leaf_three"
    LEAF_TWO = "leaf_two"
    LEARNING_APP = "learning_app"
    LIBRARY = "library"
    LIGHTBULB = "lightbulb"
    LIGHTBULB_CIRCLE = "lightbulb_circle"
    LIGHTBULB_FILAMENT = "lightbulb_filament"
    LIKERT = "likert"
    LINE_STYLE = "line_style"
    LINK = "link"
    LINK_DISMISS = "link_dismiss"
    LINK_EDIT = "link_edit"
    LINK_SQUARE = "link_square"
    LIST = "list"
    LIVE = "live"
    LIVE_OFF = "live_off"
    LOCAL_LANGUAGE = "local_language"
    LOCAL_LANGUAGE_ZI = "local_language_zi"
    LOCATION = "location"
    LOCATION_DISMISS = "location_dismiss"
    LOCATION_LIVE = "location_live"
    LOCATION_OFF = "location_off"
    LOCK_CLOSED = "lock_closed"
    LOCK_MULTIPLE = "lock_multiple"
    LOCK_OPEN = "lock_open"
    LOCK_SHIELD = "lock_shield"
    LOTTERY = "lottery"
    LUGGAGE = "luggage"
    MAIL = "mail"
    MAIL_ADD = "mail_add"
    MAIL_ALERT = "mail_alert"
    MAIL_ALL = "mail_all"
    MAIL_ARROW_UP = "mail_arrow_up"
    MAIL_CLOCK = "mail_clock"
    MAIL_COPY = "mail_copy"
    MAIL_DISMISS = "mail_dismiss"
    MAIL_ERROR = "mail_error"
    MAIL_INBOX = "mail_inbox"
    MAIL_INBOX_ADD = "mail_inbox_add"
    MAIL_INBOX_ALL = "mail_inbox_all"
    MAIL_INBOX_ARROW_RIGHT = "mail_inbox_arrow_right"
    MAIL_INBOX_ARROW_UP = "mail_inbox_arrow_up"
    MAIL_INBOX_CHECKMARK = "mail_inbox_checkmark"
    MAIL_INBOX_DISMISS = "mail_inbox_dismiss"
    MAIL_LINK = "mail_link"
    MAIL_MULTIPLE = "mail_multiple"
    MAIL_OFF = "mail_off"
    MAIL_PROHIBITED = "mail_prohibited"
    MAIL_READ = "mail_read"
    MAIL_TEMPLATE = "mail_template"
    MAIL_UNREAD = "mail_unread"
    MAP = "map"
    MAP_DRIVE = "map_drive"
    MATCH_APP_LAYOUT = "match_app_layout"
    MATH_FORMAT_LINEAR = "math_format_linear"
    MATH_FORMAT_PROFESSIONAL = "math_format_professional"
    MATH_FORMULA = "math_formula"
    MAXIMIZE = "maximize"
    MEET_NOW = "meet_now"
    MEGAPHONE = "megaphone"
    MEGAPHONE_OFF = "megaphone_off"
    MENTION = "mention"
    MERGE = "merge"
    MIC_OFF = "mic_off"
    MIC_ON = "mic_on"
    MIC_PROHIBITED = "mic_prohibited"
    MIC_SETTINGS = "mic_settings"
    MIC_SPARKLE = "mic_sparkle"
    MICROSCOPE = "microscope"
    MIDI = "midi"
    MOBILE_OPTIMIZED = "mobile_optimized"
    MOLECULE = "molecule"
    MONEY = "money"
    MONEY_CALCULATOR = "money_calculator"
    MORE_HORIZONTAL = "more_horizontal"
    MORE_VERTICAL = "more_vertical"
    MOVIES_AND_TV = "movies_and_tv"
    MULTIPLIER_1_2X = "multiplier_1_2x"
    MULTIPLIER_1_5X = "multiplier_1_5x"
    MULTIPLIER_1_8X = "multiplier_1_8x"
    MULTIPLIER_1X = "multiplier_1x"
    MULTIPLIER_2X = "multiplier_2x"
    MULTIPLIER_5X = "multiplier_5x"
    MULTISELECT = "multiselect"
    MUSIC_NOTE_1 = "music_note_1"
    MUSIC_NOTE_2 = "music_note_2"
    MY_LOCATION = "my_location"
    NAVIGATION = "navigation"
    NAVIGATION_UNREAD = "navigation_unread"
    NETWORK_CHECK = "network_check"
    NEW = "new"
    NEWS = "news"
    NEXT = "next"
    NOTE = "note"
    NOTE_ADD = "note_add"
    NOTE_EDIT = "note_edit"
    NOTEBOOK = "notebook"
    NOTEBOOK_ADD = "notebook_add"
    NOTEBOOK_ERROR = "notebook_error"
    NOTEBOOK_LIGHTNING = "notebook_lightning"
    NOTEBOOK_QUESTION_MARK = "notebook_question_mark"
    NOTEBOOK_SECTION = "notebook_section"
    NOTEBOOK_SECTION_ARROW_RIGHT = "notebook_section_arrow_right"
    NOTEBOOK_SUBSECTION = "notebook_subsection"
    NOTEBOOK_SYNC = "notebook_sync"
    NOTEPAD = "notepad"
    NOTEPAD_PERSON = "notepad_person"
    NUMBER_ROW = "number_row"
    NUMBER_SYMBOL = "number_symbol"
    NUMBER_SYMBOL_DISMISS = "number_symbol_dismiss"
    NUMBER_SYMBOL_SQUARE = "number_symbol_square"
    OFFICE_APPS = "office_apps"
    OPEN = "open"
    OPEN_FOLDER = "open_folder"
    OPEN_OFF = "open_off"
    OPTIONS = "options"
    ORGANIZATION = "organization"
    ORIENTATION = "orientation"
    PADDING_DOWN = "padding_down"
    PADDING_LEFT = "padding_left"
    PADDING_RIGHT = "padding_right"
    PADDING_TOP = "padding_top"
    PAGE_FIT = "page_fit"
    PAINT_BRUSH = "paint_brush"
    PAINT_BRUSH_ARROW_DOWN = "paint_brush_arrow_down"
    PAINT_BRUSH_ARROW_UP = "paint_brush_arrow_up"
    PAINT_BUCKET = "paint_bucket"
    PAIR = "pair"
    PANE_CLOSE = "pane_close"
    PANE_OPEN = "pane_open"
    PANEL_LEFT = "panel_left"
    PANEL_RIGHT = "panel_right"
    PANEL_RIGHT_CONTRACT = "panel_right_contract"
    PANEL_RIGHT_EXPAND = "panel_right_expand"
    PASSWORD = "password"
    PATCH = "patch"
    PATIENT = "patient"
    PAUSE = "pause"
    PAUSE_CIRCLE = "pause_circle"
    PAYMENT = "payment"
    PEOPLE = "people"
    PEOPLE_ADD = "people_add"
    PEOPLE_AUDIENCE = "people_audience"
    PEOPLE_CHECKMARK = "people_checkmark"
    PEOPLE_COMMUNITY = "people_community"
    PEOPLE_COMMUNITY_ADD = "people_community_add"
    PEOPLE_ERROR = "people_error"
    PEOPLE_MONEY = "people_money"
    PEOPLE_SEARCH = "people_search"
    PEOPLE_SETTINGS = "people_settings"
    PEOPLE_SWAP = "people_swap"
    PEOPLE_TEAM = "people_team"
    PEOPLE_TEAM_ADD = "people_team_add"
    PEOPLE_TEAM_DELETE = "people_team_delete"
    PEOPLE_TEAM_TOOLBOX = "people_team_toolbox"
    PERSON = "person"
    PERSON_ACCOUNTS = "person_accounts"
    PERSON_ADD = "person_add"
    PERSON_ARROW_LEFT = "person_arrow_left"
    PERSON_ARROW_RIGHT = "person_arrow_right"
    PERSON_AVAILABLE = "person_available"
    PERSON_BOARD = "person_board"
    PERSON_CALL = "person_call"
    PERSON_CHAT = "person_chat"
    PERSON_CLOCK = "person_clock"
    PERSON_DELETE = "person_delete"
    PERSON_FEEDBACK = "person_feedback"
    PERSON_LOCK = "person_lock"
    PERSON_MAIL = "person_mail"
    PERSON_MONEY = "person_money"
    PERSON_NOTE = "person_note"
    PERSON_PILL = "person_pill"
    PERSON_PROHIBITED = "person_prohibited"
    PERSON_QUESTION_MARK = "person_question_mark"
    PERSON_SUPPORT = "person_support"
    PERSON_SWAP = "person_swap"
    PERSON_TAG = "person_tag"
    PERSON_VOICE = "person_voice"
    PHONE = "phone"
    PHONE_ADD = "phone_add"
    PHONE_ARROW_RIGHT = "phone_arrow_right"
    PHONE_DESKTOP = "phone_desktop"
    PHONE_DISMISS = "phone_dismiss"
    PHONE_LAPTOP = "phone_laptop"
    PHONE_LINK_SETUP = "phone_link_setup"
    PHONE_LOCK = "phone_lock"
    PHONE_PAGE_HEADER = "phone_page_header"
    PHONE_PAGINATION = "phone_pagination"
    PHONE_SCREEN_TIME = "phone_screen_time"
    PHONE_SHAKE = "phone_shake"
    PHONE_SPAN_IN = "phone_span_in"
    PHONE_SPAN_OUT = "phone_span_out"
    PHONE_SPEAKER = "phone_speaker"
    PHONE_STATUS_BAR = "phone_status_bar"
    PHONE_TABLET = "phone_tablet"
    PHONE_UPDATE = "phone_update"
    PHONE_VERTICAL_SCROLL = "phone_vertical_scroll"
    PHONE_VIBRATE = "phone_vibrate"
    PHOTO_FILTER = "photo_filter"
    PI = "pi"
    PICTURE_IN_PICTURE = "picture_in_picture"
    PILL = "pill"
    PIN = "pin"
    PIN_OFF = "pin_off"
    PIVOT = "pivot"
    PLAY = "play"
    PLAY_CIRCLE = "play_circle"
    PLUG_DISCONNECTED = "plug_disconnected"
    POINT_SCAN = "point_scan"
    POLL = "poll"
    PORT_HDMI = "port_hdmi"
    PORT_MICRO_USB = "port_micro_usb"
    PORT_USB_A = "port_usb_a"
    PORT_USB_C = "port_usb_c"
    POSITION_BACKWARD = "position_backward"
    POSITION_FORWARD = "position_forward"
    POSITION_TO_BACK = "position_to_back"
    POSITION_TO_FRONT = "position_to_front"
    POWER = "power"
    PREDICTIONS = "predictions"
    PREMIUM = "premium"
    PREMIUM_PERSON = "premium_person"
    PRESENTER = "presenter"
    PRESENTER_OFF = "presenter_off"
    PREVIEW_LINK = "preview_link"
    PREVIOUS = "previous"
    PRINT = "print"
    PRINT_ADD = "print_add"
    PRODUCTION = "production"
    PRODUCTION_CHECKMARK = "production_checkmark"
    PROHIBITED = "prohibited"
    PROHIBITED_MULTIPLE = "prohibited_multiple"
    PROJECTION_SCREEN = "projection_screen"
    PROJECTION_SCREEN_DISMISS = "projection_screen_dismiss"
    PROTOCOL_HANDLER = "protocol_handler"
    PULSE = "pulse"
    PULSE_SQUARE = "pulse_square"
    PUZZLE_CUBE = "puzzle_cube"
    PUZZLE_PIECE = "puzzle_piece"
    QR_CODE = "qr_code"
    QUESTION = "question"
    QUESTION_CIRCLE = "question_circle"
    QUIZ_NEW = "quiz_new"
    RADIO_BUTTON = "radio_button"
    RATING_MATURE = "rating_mature"
    RATIO_ONE_TO_ONE = "ratio_one_to_one"
    RE_ORDER = "re_order"
    RE_ORDER_DOTS_HORIZONTAL = "re_order_dots_horizontal"
    RE_ORDER_DOTS_VERTICAL = "re_order_dots_vertical"
    READ_ALOUD = "read_aloud"
    READING_LIST = "reading_list"
    READING_LIST_ADD = "reading_list_add"
    READING_MODE_MOBILE = "reading_mode_mobile"
    REAL_ESTATE = "real_estate"
    RECEIPT = "receipt"
    RECEIPT_ADD = "receipt_add"
    RECEIPT_BAG = "receipt_bag"
    RECEIPT_CUBE = "receipt_cube"
    RECEIPT_MONEY = "receipt_money"
    RECEIPT_PLAY = "receipt_play"
    RECORD = "record"
    RECORD_STOP = "record_stop"
    RECTANGLE_LANDSCAPE = "rectangle_landscape"
    RENAME = "rename"
    RESIZE_IMAGE = "resize_image"
    RESIZE_LARGE = "resize_large"
    RESIZE_SMALL = "resize_small"
    RESIZE_TABLE = "resize_table"
    RESIZE_VIDEO = "resize_video"
    REWARD = "reward"
    REWIND = "rewind"
    RIBBON = "ribbon"
    RIBBON_ADD = "ribbon_add"
    RIBBON_STAR = "ribbon_star"
    ROAD_CONE = "road_cone"
    ROCKET = "rocket"
    ROTATE_LEFT = "rotate_left"
    ROTATE_RIGHT = "rotate_right"
    ROUTER = "router"
    ROW_TRIPLE = "row_triple"
    RSS = "rss"
    RULER = "ruler"
    RUN = "run"
    SAVE = "save"
    SAVE_ARROW_RIGHT = "save_arrow_right"
    SAVE_COPY = "save_copy"
    SAVE_EDIT = "save_edit"
    SAVINGS = "savings"
    SCALE_FILL = "scale_fill"
    SCALE_FIT = "scale_fit"
    SCALES = "scales"
    SCAN = "scan"
    SCAN_OBJECT = "scan_object"
    SCAN_TABLE = "scan_table"
    SCAN_TEXT = "scan_text"
    SCAN_THUMB_UP = "scan_thumb_up"
    SCAN_THUMB_UP_OFF = "scan_thumb_up_off"
    SCAN_TYPE = "scan_type"
    SCRATCHPAD = "scratchpad"
    SCREENSHOT = "screenshot"
    SEARCH = "search"
    SEARCH_INFO = "search_info"
    SEARCH_SQUARE = "search_square"
    SEARCH_VISUAL = "search_visual"
    SELECT_ALL_OFF = "select_all_off"
    SELECT_ALL_ON = "select_all_on"
    SELECT_OBJECT = "select_object"
    SEND = "send"
    SEND_CLOCK = "send_clock"
    SEND_COPY = "send_copy"
    SERIAL_PORT = "serial_port"
    SERVER = "server"
    SERVICE_BELL = "service_bell"
    SET_TOP_STACK = "set_top_stack"
    SETTINGS = "settings"
    SHAPE_EXCLUDE = "shape_exclude"
    SHAPE_INTERSECT = "shape_intersect"
    SHAPE_SUBTRACT = "shape_subtract"
    SHAPE_UNION = "shape_union"
    SHAPES = "shapes"
    SHARE = "share"
    SHARE_ANDROID = "share_android"
    SHARE_CLOSE_TRAY = "share_close_tray"
    SHARE_IOS = "share_ios"
    SHARE_SCREEN_PERSON = "share_screen_person"
    SHARE_SCREEN_PERSON_OVERLAY = "share_screen_person_overlay"
    SHARE_SCREEN_PERSON_OVERLAY_INSIDE = "share_screen_person_overlay_inside"
    SHARE_SCREEN_START = "share_screen_start"
    SHARE_SCREEN_STOP = "share_screen_stop"
    SHIELD = "shield"
    SHIELD_BADGE = "shield_badge"
    SHIELD_CHECKMARK = "shield_checkmark"
    SHIELD_DISMISS = "shield_dismiss"
    SHIELD_ERROR = "shield_error"
    SHIELD_KEYHOLE = "shield_keyhole"
    SHIELD_PROHIBITED = "shield_prohibited"
    SHIELD_TASK = "shield_task"
    SHIELD_VIDEO = "shield_video"
    SHIFTS = "shifts"
    SHIFTS_30_MINUTES = "shifts_30_minutes"
    SHIFTS_ACTIVITY = "shifts_activity"
    SHIFTS_ADD = "shifts_add"
    SHIFTS_AVAILABILITY = "shifts_availability"
    SHIFTS_CHECKMARK = "shifts_checkmark"
    SHIFTS_DAY = "shifts_day"
    SHIFTS_OPEN = "shifts_open"
    SHIFTS_PROHIBITED = "shifts_prohibited"
    SHIFTS_QUESTION_MARK = "shifts_question_mark"
    SHIFTS_TEAM = "shifts_team"
    SHOPPING_BAG = "shopping_bag"
    SHORTPICK = "shortpick"
    SIGN_OUT = "sign_out"
    SIGNATURE = "signature"
    SIGNED = "signed"
    SIM = "sim"
    SKIP_BACKWARD_10 = "skip_backward_10"
    SKIP_FORWARD_10 = "skip_forward_10"
    SKIP_FORWARD_30 = "skip_forward_30"
    SKIP_FORWARD_TAB = "skip_forward_tab"
    SLEEP = "sleep"
    SLIDE_ADD = "slide_add"
    SLIDE_DESIGN = "slide_design"
    SLIDE_ERASER = "slide_eraser"
    SLIDE_GRID = "slide_grid"
    SLIDE_HIDE = "slide_hide"
    SLIDE_LAYOUT = "slide_layout"
    SLIDE_MICROPHONE = "slide_microphone"
    SLIDE_MULTIPLE = "slide_multiple"
    SLIDE_MULTIPLE_ARROW_RIGHT = "slide_multiple_arrow_right"
    SLIDE_MULTIPLE_SEARCH = "slide_multiple_search"
    SLIDE_SEARCH = "slide_search"
    SLIDE_SETTINGS = "slide_settings"
    SLIDE_SIZE = "slide_size"
    SLIDE_TEXT = "slide_text"
    SLIDE_TRANSITION = "slide_transition"
    SMARTWATCH = "smartwatch"
    SMARTWATCH_DOT = "smartwatch_dot"
    SNOOZE = "snooze"
    SOUND_SOURCE = "sound_source"
    SPACEBAR = "spacebar"
    SPARKLE = "sparkle"
    SPEAKER_0 = "speaker_0"
    SPEAKER_1 = "speaker_1"
    SPEAKER_2 = "speaker_2"
    SPEAKER_BLUETOOTH = "speaker_bluetooth"
    SPEAKER_EDIT = "speaker_edit"
    SPEAKER_MUTE = "speaker_mute"
    SPEAKER_OFF = "speaker_off"
    SPEAKER_SETTINGS = "speaker_settings"
    SPEAKER_USB = "speaker_usb"
    SPLIT_HORIZONTAL = "split_horizontal"
    SPLIT_VERTICAL = "split_vertical"
    SPORT = "sport"
    SPORT_AMERICAN_FOOTBALL = "sport_american_football"
    SPORT_BASEBALL = "sport_baseball"
    SPORT_BASKETBALL = "sport_basketball"
    SPORT_HOCKEY = "sport_hockey"
    SPORT_SOCCER = "sport_soccer"
    SQUARE_ARROW_FORWARD = "square_arrow_forward"
    SQUARE_MULTIPLE = "square_multiple"
    STACK = "stack"
    STACK_STAR = "stack_star"
    STAR = "star"
    STAR_ADD = "star_add"
    STAR_ARROW_RIGHT_END = "star_arrow_right_end"
    STAR_ARROW_RIGHT_START = "star_arrow_right_start"
    STAR_EDIT = "star_edit"
    STAR_EMPHASIS = "star_emphasis"
    STAR_HALF = "star_half"
    STAR_LINE_HORIZONTAL_3 = "star_line_horizontal_3"
    STAR_OFF = "star_off"
    STAR_ONE_QUARTER = "star_one_quarter"
    STAR_PROHIBITED = "star_prohibited"
    STAR_SETTINGS = "star_settings"
    STAR_THREE_QUARTER = "star_three_quarter"
    STATUS = "status"
    STEPS = "steps"
    STETHOSCOPE = "stethoscope"
    STICKER = "sticker"
    STICKER_ADD = "sticker_add"
    STOP = "stop"
    STORAGE = "storage"
    STORE_MICROSOFT = "store_microsoft"
    STREAM = "stream"
    STRIKETHROUGH_GA_NA = "strikethrough_ga_na"
    STYLE_GUIDE = "style_guide"
    SUB_GRID = "sub_grid"
    SUBTRACT = "subtract"
    SUBTRACT_CIRCLE = "subtract_circle"
    SUBTRACT_SQUARE = "subtract_square"
    SURFACE_EARBUDS = "surface_earbuds"
    SURFACE_HUB = "surface_hub"
    SWIPE_DOWN = "swipe_down"
    SWIPE_RIGHT = "swipe_right"
    SWIPE_UP = "swipe_up"
    SYMBOLS = "symbols"
    SYRINGE = "syringe"
    SYSTEM = "system"
    TAB = "tab"
    TAB_ADD = "tab_add"
    TAB_ARROW_LEFT = "tab_arrow_left"
    TAB_DESKTOP_ARROW_CLOCKWISE = "tab_desktop_arrow_clockwise"
    TAB_DESKTOP_BOTTOM = "tab_desktop_bottom"
    TAB_DESKTOP_IMAGE = "tab_desktop_image"
    TAB_DESKTOP_MULTIPLE_BOTTOM = "tab_desktop_multiple_bottom"
    TAB_IN_PRIVATE = "tab_in_private"
    TAB_INPRIVATE_ACCOUNT = "tab_inprivate_account"
    TAB_PROHIBITED = "tab_prohibited"
    TAB_SHIELD_DISMISS = "tab_shield_dismiss"
    TABLE = "table"
    TABLE_ADD = "table_add"
    TABLE_CELL_EDIT = "table_cell_edit"
    TABLE_CELLS_MERGE = "table_cells_merge"
    TABLE_CELLS_SPLIT = "table_cells_split"
    TABLE_DELETE_COLUMN = "table_delete_column"
    TABLE_DELETE_ROW = "table_delete_row"
    TABLE_DISMISS = "table_dismiss"
    TABLE_EDIT = "table_edit"
    TABLE_FREEZE_COLUMN = "table_freeze_column"
    TABLE_FREEZE_COLUMN_AND_ROW = "table_freeze_column_and_row"
    TABLE_FREEZE_ROW = "table_freeze_row"
    TABLE_INSERT_COLUMN = "table_insert_column"
    TABLE_INSERT_ROW = "table_insert_row"
    TABLE_MOVE_ABOVE = "table_move_above"
    TABLE_MOVE_BELOW = "table_move_below"
    TABLE_MOVE_LEFT = "table_move_left"
    TABLE_MOVE_RIGHT = "table_move_right"
    TABLE_RESIZE_COLUMN = "table_resize_column"
    TABLE_RESIZE_ROW = "table_resize_row"
    TABLE_SETTINGS = "table_settings"
    TABLE_SIMPLE = "table_simple"
    TABLE_STACK_ABOVE = "table_stack_above"
    TABLE_STACK_BELOW = "table_stack_below"
    TABLE_STACK_LEFT = "table_stack_left"
    TABLE_STACK_RIGHT = "table_stack_right"
    TABLE_SWITCH = "table_switch"
    TABLET = "tablet"
    TABLET_SPEAKER = "tablet_speaker"
    TABS = "tabs"
    TAG = "tag"
    TAG_DISMISS = "tag_dismiss"
    TAG_LOCK = "tag_lock"
    TAG_LOCK_ACCENT = "tag_lock_accent"
    TAG_QUESTION_MARK = "tag_question_mark"
    TAP_DOUBLE = "tap_double"
    TAP_SINGLE = "tap_single"
    TARGET = "target"
    TARGET_ARROW = "target_arrow"
    TARGET_EDIT = "target_edit"
    TASK_LIST_ADD = "task_list_add"
    TASK_LIST_LTR = "task_list_ltr"
    TASK_LIST_RTL = "task_list_rtl"
    TASK_LIST_SQUARE_ADD = "task_list_square_add"
    TASK_LIST_SQUARE_LTR = "task_list_square_ltr"
    TASK_LIST_SQUARE_RTL = "task_list_square_rtl"
    TASKS_APP = "tasks_app"
    TEDDY = "teddy"
    TEMPERATURE = "temperature"
    TENT = "tent"
    TETRIS_APP = "tetris_app"
    TEXT = "text"
    TEXT_ADD = "text_add"
    TEXT_ADD_SPACE_AFTER = "text_add_space_after"
    TEXT_ADD_SPACE_BEFORE = "text_add_space_before"
    TEXT_ADD_T = "text_add_t"
    TEXT_ALIGN_CENTER = "text_align_center"
    TEXT_ALIGN_CENTER_ROTATE_270 = "text_align_center_rotate_270"
    TEXT_ALIGN_DISTRIBUTED = "text_align_distributed"
    TEXT_ALIGN_DISTRIBUTED_EVENLY = "text_align_distributed_evenly"
    TEXT_ALIGN_DISTRIBUTED_VERTICAL = "text_align_distributed_vertical"
    TEXT_ALIGN_JUSTIFY = "text_align_justify"
    TEXT_ALIGN_JUSTIFY_LOW = "text_align_justify_low"
    TEXT_ALIGN_JUSTIFY_LOW_ROTATE_90 = "text_align_justify_low_rotate_90"
    TEXT_ALIGN_JUSTIFY_ROTATE_90 = "text_align_justify_rotate_90"
    TEXT_ALIGN_LEFT = "text_align_left"
    TEXT_ALIGN_LEFT_ROTATE_270 = "text_align_left_rotate_270"
    TEXT_ALIGN_RIGHT = "text_align_right"
    TEXT_ALIGN_RIGHT_ROTATE_270 = "text_align_right_rotate_270"
    TEXT_BOLD = "text_bold"
    TEXT_BULLET_LIST_ADD = "text_bullet_list_add"
    TEXT_BULLET_LIST_LTR = "text_bullet_list_ltr"
    TEXT_BULLET_LIST_RTL = "text_bullet_list_rtl"
    TEXT_BULLET_LIST_SQUARE = "text_bullet_list_square"
    TEXT_BULLET_LIST_SQUARE_EDIT = "text_bullet_list_square_edit"
    TEXT_BULLET_LIST_SQUARE_WARNING = "text_bullet_list_square_warning"
    TEXT_BULLET_LIST_TREE = "text_bullet_list_tree"
    TEXT_CASE_LOWERCASE = "text_case_lowercase"
    TEXT_CASE_TITLE = "text_case_title"
    TEXT_CASE_UPPERCASE = "text_case_uppercase"
    TEXT_CHANGE_CASE = "text_change_case"
    TEXT_CLEAR_FORMATTING = "text_clear_formatting"
    TEXT_CLEAR_FORMATTING_GA = "text_clear_formatting_ga"
    TEXT_COLLAPSE = "text_collapse"
    TEXT_COLOR = "text_color"
    TEXT_COLOR_ACCENT = "text_color_accent"
    TEXT_COLOR_GA = "text_color_ga"
    TEXT_COLUMN_ONE = "text_column_one"
    TEXT_COLUMN_ONE_NARROW = "text_column_one_narrow"
    TEXT_COLUMN_ONE_WIDE = "text_column_one_wide"
    TEXT_COLUMN_THREE = "text_column_three"
    TEXT_COLUMN_TWO = "text_column_two"
    TEXT_COLUMN_TWO_LEFT = "text_column_two_left"
    TEXT_COLUMN_TWO_RIGHT = "text_column_two_right"
    TEXT_CONTINUOUS = "text_continuous"
    TEXT_DESCRIPTION = "text_description"
    TEXT_DIRECTION_HORIZONTAL_LEFT = "text_direction_horizontal_left"
    TEXT_DIRECTION_HORIZONTAL_LTR = "text_direction_horizontal_ltr"
    TEXT_DIRECTION_HORIZONTAL_RIGHT = "text_direction_horizontal_right"
    TEXT_DIRECTION_HORIZONTAL_RTL = "text_direction_horizontal_rtl"
    TEXT_DIRECTION_ROTATE_270_LTR = "text_direction_rotate_270_ltr"
    TEXT_DIRECTION_ROTATE_270_RIGHT = "text_direction_rotate_270_right"
    TEXT_DIRECTION_ROTATE_90_LEFT = "text_direction_rotate_90_left"
    TEXT_DIRECTION_ROTATE_90_LTR = "text_direction_rotate_90_ltr"
    TEXT_DIRECTION_ROTATE_90_RIGHT = "text_direction_rotate_90_right"
    TEXT_DIRECTION_ROTATE_90_RTL = "text_direction_rotate_90_rtl"
    TEXT_DIRECTION_VERTICAL = "text_direction_vertical"
    TEXT_EDIT_STYLE = "text_edit_style"
    TEXT_EDIT_STYLE_GA = "text_edit_style_ga"
    TEXT_EFFECTS = "text_effects"
    TEXT_EFFECTS_GA = "text_effects_ga"
    TEXT_EXPAND = "text_expand"
    TEXT_FIELD = "text_field"
    TEXT_FIRST_LINE = "text_first_line"
    TEXT_FONT = "text_font"
    TEXT_FONT_SIZE = "text_font_size"
    TEXT_FOOTNOTE = "text_footnote"
    TEXT_FOOTNOTE_GA_NA = "text_footnote_ga_na"
    TEXT_GRAMMAR_ARROW_LEFT = "text_grammar_arrow_left"
    TEXT_GRAMMAR_ARROW_RIGHT = "text_grammar_arrow_right"
    TEXT_GRAMMAR_CHECKMARK = "text_grammar_checkmark"
    TEXT_GRAMMAR_DISMISS = "text_grammar_dismiss"
    TEXT_GRAMMAR_SETTINGS = "text_grammar_settings"
    TEXT_GRAMMAR_WAND = "text_grammar_wand"
    TEXT_HANGING = "text_hanging"
    TEXT_HEADER_1 = "text_header_1"
    TEXT_HEADER_2 = "text_header_2"
    TEXT_HEADER_3 = "text_header_3"
    TEXT_INDENT_DECREASE = "text_indent_decrease"
    TEXT_INDENT_DECREASE_LTR = "text_indent_decrease_ltr"
    TEXT_INDENT_DECREASE_RTL = "text_indent_decrease_rtl"
    TEXT_INDENT_INCREASE = "text_indent_increase"
    TEXT_INDENT_INCREASE_LTR = "text_indent_increase_ltr"
    TEXT_INDENT_INCREASE_RTL = "text_indent_increase_rtl"
    TEXT_ITALIC = "text_italic"
    TEXT_LINE_SPACING = "text_line_spacing"
    TEXT_MORE = "text_more"
    TEXT_NUMBER_FORMAT = "text_number_format"
    TEXT_NUMBER_FORMAT_GA_NA_DA = "text_number_format_ga_na_da"
    TEXT_NUMBER_LIST_LTR = "text_number_list_ltr"
    TEXT_NUMBER_LIST_RTL = "text_number_list_rtl"
    TEXT_PARAGRAPH = "text_paragraph"
    TEXT_PARAGRAPH_DIRECTION = "text_paragraph_direction"
    TEXT_POSITION_BEHIND = "text_position_behind"
    TEXT_POSITION_FRONT = "text_position_front"
    TEXT_POSITION_LINE = "text_position_line"
    TEXT_POSITION_SQUARE = "text_position_square"
    TEXT_POSITION_THROUGH = "text_position_through"
    TEXT_POSITION_TIGHT = "text_position_tight"
    TEXT_POSITION_TOP_BOTTOM = "text_position_top_bottom"
    TEXT_PROOFING_TOOLS = "text_proofing_tools"
    TEXT_PROOFING_TOOLS_GA_NA_DA = "text_proofing_tools_ga_na_da"
    TEXT_PROOFING_TOOLS_ZI = "text_proofing_tools_zi"
    TEXT_QUOTE = "text_quote"
    TEXT_SORT_ASCENDING = "text_sort_ascending"
    TEXT_SORT_DESCENDING = "text_sort_descending"
    TEXT_STRIKETHROUGH = "text_strikethrough"
    TEXT_STRIKETHROUGH_S = "text_strikethrough_s"
    TEXT_SUBSCRIPT = "text_subscript"
    TEXT_SUPERSCRIPT = "text_superscript"
    TEXT_T = "text_t"
    TEXT_UNDERLINE = "text_underline"
    TEXT_WORD_COUNT = "text_word_count"
    TEXT_WRAP = "text_wrap"
    TEXTBOX = "textbox"
    TEXTBOX_ALIGN_BOTTOM = "textbox_align_bottom"
    TEXTBOX_ALIGN_BOTTOM_ROTATE_90 = "textbox_align_bottom_rotate_90"
    TEXTBOX_ALIGN_CENTER = "textbox_align_center"
    TEXTBOX_ALIGN_MIDDLE = "textbox_align_middle"
    TEXTBOX_ALIGN_MIDDLE_ROTATE_90 = "textbox_align_middle_rotate_90"
    TEXTBOX_ALIGN_TOP = "textbox_align_top"
    TEXTBOX_ALIGN_TOP_ROTATE_90 = "textbox_align_top_rotate_90"
    TEXTBOX_MORE = "textbox_more"
    TEXTBOX_VERTICAL = "textbox_vertical"
    THINKING = "thinking"
    THUMB_DISLIKE = "thumb_dislike"
    THUMB_LIKE = "thumb_like"
    TICKET_DIAGONAL = "ticket_diagonal"
    TICKET_HORIZONTAL = "ticket_horizontal"
    TIME_AND_WEATHER = "time_and_weather"
    TIME_PICKER = "time_picker"
    TIMELINE = "timeline"
    TIMER = "timer"
    TIMER_10 = "timer_10"
    TIMER_2 = "timer_2"
    TIMER_3 = "timer_3"
    TIMER_OFF = "timer_off"
    TOGGLE_LEFT = "toggle_left"
    TOGGLE_RIGHT = "toggle_right"
    TOOLBOX = "toolbox"
    TOOLTIP_QUOTE = "tooltip_quote"
    TOP_SPEED = "top_speed"
    TRANSLATE = "translate"
    TRANSMISSION = "transmission"
    TROPHY = "trophy"
    TV = "tv"
    TV_USB = "tv_usb"
    UMBRELLA = "umbrella"
    UNINSTALL_APP = "uninstall_app"
    USB_PLUG = "usb_plug"
    USB_PORT = "usb_port"
    USB_STICK = "usb_stick"
    VAULT = "vault"
    VEHICLE_BICYCLE = "vehicle_bicycle"
    VEHICLE_BUS = "vehicle_bus"
    VEHICLE_CAB = "vehicle_cab"
    VEHICLE_CAR = "vehicle_car"
    VEHICLE_CAR_COLLISION = "vehicle_car_collision"
    VEHICLE_SHIP = "vehicle_ship"
    VEHICLE_SUBWAY = "vehicle_subway"
    VEHICLE_TRUCK = "vehicle_truck"
    VEHICLE_TRUCK_PROFILE = "vehicle_truck_profile"
    VIDEO = "video"
    VIDEO_360 = "video_360"
    VIDEO_ADD = "video_add"
    VIDEO_BACKGROUND_EFFECT = "video_background_effect"
    VIDEO_CLIP = "video_clip"
    VIDEO_OFF = "video_off"
    VIDEO_PERSON = "video_person"
    VIDEO_PERSON_CALL = "video_person_call"
    VIDEO_PERSON_OFF = "video_person_off"
    VIDEO_PERSON_SPARKLE = "video_person_sparkle"
    VIDEO_PERSON_STAR = "video_person_star"
    VIDEO_PERSON_STAR_OFF = "video_person_star_off"
    VIDEO_PLAY_PAUSE = "video_play_pause"
    VIDEO_PROHIBITED = "video_prohibited"
    VIDEO_SECURITY = "video_security"
    VIDEO_SWITCH = "video_switch"
    VIEW_DESKTOP = "view_desktop"
    VIEW_DESKTOP_MOBILE = "view_desktop_mobile"
    VOICEMAIL = "voicemail"
    VOTE = "vote"
    WALKIE_TALKIE = "walkie_talkie"
    WALLET = "wallet"
    WALLPAPER = "wallpaper"
    WAND = "wand"
    WARNING = "warning"
    WEATHER_BLOWING_SNOW = "weather_blowing_snow"
    WEATHER_CLOUDY = "weather_cloudy"
    WEATHER_DRIZZLE = "weather_drizzle"
    WEATHER_DUSTSTORM = "weather_duststorm"
    WEATHER_FOG = "weather_fog"
    WEATHER_HAIL_DAY = "weather_hail_day"
    WEATHER_HAIL_NIGHT = "weather_hail_night"
    WEATHER_HAZE = "weather_haze"
    WEATHER_MOON = "weather_moon"
    WEATHER_MOON_OFF = "weather_moon_off"
    WEATHER_PARTLY_CLOUDY_DAY = "weather_partly_cloudy_day"
    WEATHER_PARTLY_CLOUDY_NIGHT = "weather_partly_cloudy_night"
    WEATHER_RAIN = "weather_rain"
    WEATHER_RAIN_SHOWERS_DAY = "weather_rain_showers_day"
    WEATHER_RAIN_SHOWERS_NIGHT = "weather_rain_showers_night"
    WEATHER_RAIN_SNOW = "weather_rain_snow"
    WEATHER_SNOW = "weather_snow"
    WEATHER_SNOW_SHOWER_DAY = "weather_snow_shower_day"
    WEATHER_SNOW_SHOWER_NIGHT = "weather_snow_shower_night"
    WEATHER_SNOWFLAKE = "weather_snowflake"
    WEATHER_SQUALLS = "weather_squalls"
    WEATHER_SUNNY = "weather_sunny"
    WEATHER_SUNNY_HIGH = "weather_sunny_high"
    WEATHER_SUNNY_LOW = "weather_sunny_low"
    WEATHER_THUNDERSTORM = "weather_thunderstorm"
    WEB_ASSET = "web_asset"
    WHITEBOARD = "whiteboard"
    WIFI_1 = "wifi_1"
    WIFI_2 = "wifi_2"
    WIFI_3 = "wifi_3"
    WIFI_4 = "wifi_4"
    WIFI_LOCK = "wifi_lock"
    WIFI_OFF = "wifi_off"
    WIFI_PROTECTED = "wifi_protected"
    WIFI_WARNING = "wifi_warning"
    WINDOW = "window"
    WINDOW_ARROW_UP = "window_arrow_up"
    WINDOW_DEV_TOOLS = "window_dev_tools"
    WINDOW_NEW = "window_new"
    WINDOW_SHIELD = "window_shield"
    WRENCH = "wrench"
    XBOX_CONSOLE = "xbox_console"
    XRAY = "xray"
    ZOOM_IN = "zoom_in"
    ZOOM_OUT = "zoom_out"


ICON_TEMPLATE = "ic_fluent_{name}_{size}_{style}.svg"
ICON_SIZE = "24"


class FluentIcon(ft.Image):
    def __init__(
        self,
        name: FluentIcons,
        style: FluentIconStyle = FluentIconStyle.REGULAR,
        color: str = "#ffffff",
        size: int = 24,
    ):
        if name in FluentIcons:
            icon_path = Path(__file__).parent.joinpath(
                "static",
                "icons",
                ICON_TEMPLATE.format(
                    name=name.value, size=ICON_SIZE, style=style.value
                ),
            )
            with open(icon_path, "r") as f:
                svg_content = f.read()

            if color:
                svg_content = re.sub(r'fill="[^"]+"', f'fill="{color}"', svg_content)

            super().__init__(src=svg_content, width=size, height=size)
        else:
            raise Exception("No icon named", name)
